<?php
/**
 * 2024 Sedestral
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@sedestral.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    Sedestral <contact@sedestral.com>
 * @copyright 2024 Sedestral
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 * International Registered Trademark & Property of Sedestral
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

class SedestralCategory extends ObjectModel
{
    public $id_sedestral_category;
    public $id_lang;
    public $title;
    public $snippet;
    public $state;
    public $route;
    public $sitemap_priority;

    public static $definition = [
        'table' => 'sedestral_category',
        'primary' => 'id_sedestral_category',
        // Removed 'multilang' as each category is single-language
        'fields' => [
            'id_lang' => ['type' => self::TYPE_INT, 'validate' => 'isUnsignedInt', 'required' => true],
            'state' => ['type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'size' => 10],
            'title' => ['type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'required' => true, 'size' => 255],
            'snippet' => ['type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'size' => 500],
            'route' => ['type' => self::TYPE_STRING, 'validate' => 'isLinkRewrite', 'required' => true, 'size' => 255],
            'sitemap_priority' => ['type' => self::TYPE_FLOAT, 'validate' => 'isFloat', 'required' => true],
        ],
    ];

    /**
     * Override the delete method to remove associated posts.
     *
     * @return bool
     */
    public function delete()
    {
        // Delete associated posts
        $posts = new PrestaShopCollection('SedestralPost');
        $posts->where('id_sedestral_category', '=', $this->id_sedestral_category);

        foreach ($posts as $post) {
            $post->delete();
        }

        // Call the parent delete method
        return parent::delete();
    }

    /**
     * Get categories based on language.
     *
     * @param int $id_lang
     *
     * @return array
     */
    public static function getCategories($id_lang)
    {
        $sql = 'SELECT mc.`id_sedestral_category`, mc.`title`
            FROM `' . _DB_PREFIX_ . 'sedestral_category` mc
            WHERE mc.`id_lang` = ' . pSQL($id_lang) . '
            ORDER BY mc.`title` ASC';

        return Db::getInstance()->executeS($sql);
    }

    public function getByRoute($route, $id_lang)
    {
        $sql = 'SELECT * FROM ' . _DB_PREFIX_ . 'sedestral_category
            WHERE `route` = \'' . pSQL($route) . '\'
            AND `state` = \'publish\'
            AND id_lang = ' . pSQL($id_lang);

        // Pour déboguer, vous pouvez imprimer la requête SQL
        // echo $sql;

        $result = Db::getInstance()->getRow($sql); // getRow renvoie le premier résultat

        if ($result) {
            $this->hydrate($result);

            return $this;
        }

        return null;
    }
}
