<?php
/**
 * 2024 Sedestral
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@sedestral.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    Sedestral <contact@sedestral.com>
 * @copyright 2024 Sedestral
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 * International Registered Trademark & Property of Sedestral
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

class SedestralPost extends ObjectModel
{
    public $id_sedestral_post;
    public $id_sedestral_category;
    public $id_lang;
    public $title;
    public $snippet;
    public $content;
    public $keywords;
    public $author;
    public $cover;
    public $route;
    public $state;
    public $sitemap_priority;
    public $date_published;

    public static $definition = [
        'table' => 'sedestral_post',
        'primary' => 'id_sedestral_post',
        'fields' => [
            'id_sedestral_category' => ['type' => self::TYPE_INT, 'validate' => 'isUnsignedInt', 'required' => true],
            'id_lang' => ['type' => self::TYPE_INT, 'validate' => 'isUnsignedInt', 'required' => true],
            'author' => ['type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'size' => 255],
            'cover' => ['type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'size' => 255],
            'state' => ['type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'size' => 10, 'required' => true],
            'title' => ['type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'required' => true, 'size' => 1000],
            'snippet' => ['type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'required' => true, 'size' => 1000],
            'content' => ['type' => self::TYPE_HTML, 'validate' => 'isCleanHtml', 'required' => true],
            'keywords' => ['type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'size' => 1000],
            'route' => ['type' => self::TYPE_STRING, 'validate' => 'isLinkRewrite', 'required' => true, 'size' => 255],
            'sitemap_priority' => ['type' => self::TYPE_FLOAT, 'validate' => 'isFloat', 'required' => true],
            'date_published' => [
                'type' => self::TYPE_DATE,
                'validate' => 'isDateFormat',
                'required' => false,
                'copy_post' => false,
            ],
        ],
    ];

    public function loadImages($context)
    {
        $escapedPath = preg_quote(_PS_TMP_IMG_, '/');
        $regex = '/<img[^>]*src=[\'"][^\'"]*' . $escapedPath . '([^\'"]+)[\'"]/i';
        preg_match_all($regex, $this->content, $matches);
        foreach ($matches[1] as $match) {
            $this->getCoverThumbnailUrl($context, $match, 'url');
        }
    }

    public function getCoverThumbnailUrl($context, $path, $mode = 'url')
    {
        if ($path) {
            $imagePath = _PS_IMG_DIR_ . 'modules/sedestral/' . $path;
            if (file_exists($imagePath)) {
                $thumbnailHtml = ImageManager::thumbnail(
                    $imagePath,
                    $path,
                    2500,
                    null,
                    false
                );

                // Si le mode est 'html', renvoyer directement l'élément <img>
                if ($mode === 'html') {
                    return $thumbnailHtml;
                }

                // Si le mode est 'url', extraire l'URL de la vignette
                if (preg_match('/src="([^"]+)"/', $thumbnailHtml, $matches)) {
                    return rtrim($context->shop->getBaseURL(), '/') . '/' . ltrim($matches[1], '/');
                }
            }
        }

        return null;
    }

    public function getCategoryRoute()
    {
        $category = new SedestralCategory($this->id_sedestral_category, $this->id_lang);
        return $category->route;
    }

    public static function fetchPosts($whereClause, $offset, $limit)
    {
        $sql = '
        SELECT p.*, c.route AS category_route
        FROM ' . _DB_PREFIX_ . 'sedestral_post p
        LEFT JOIN ' . _DB_PREFIX_ . 'sedestral_category c ON (p.id_sedestral_category = c.id_sedestral_category)
        WHERE ' . $whereClause . '
        AND c.state = "publish"
        AND p.state = "publish"
        AND p.date_published <= NOW()
        ORDER BY p.date_published DESC
        LIMIT ' . $limit . ' OFFSET ' . $offset;

        return Db::getInstance()->executeS($sql);
    }
}
