<?php
/**
 * 2024 Sedestral
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@sedestral.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    Sedestral <contact@sedestral.com>
 * @copyright 2024 Sedestral
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 * International Registered Trademark & Property of Sedestral
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

class SedestralPostStats extends ObjectModel
{
    public $id;
    public $post_id;
    public $count;
    public $timestamp;

    public static $definition = [
        'table' => 'sedestral_post_stats',
        'primary' => 'id',
        'fields' => [
            'post_id' => ['type' => self::TYPE_INT, 'validate' => 'isUnsignedInt', 'required' => true],
            'count' => ['type' => self::TYPE_INT, 'validate' => 'isUnsignedInt', 'required' => true],
            'timestamp' => ['type' => self::TYPE_DATE, 'validate' => 'isDateFormat', 'required' => true],
        ],
    ];

    public static function incrementCount($post_id)
    {
        $date = date('Y-m-d') . ' 00:00:00';
        $sql = 'SELECT `id`, `count` FROM `' . _DB_PREFIX_ . 'sedestral_post_stats`
                WHERE `post_id` = ' . (int) $post_id . '
                AND `timestamp` = "' . pSQL($date) . '"';
        $row = Db::getInstance()->getRow($sql);

        if ($row) {
            // Entry exists, increment count
            $id = $row['id'];
            $count = $row['count'] + 1;
            Db::getInstance()->update('sedestral_post_stats', ['count' => $count], 'id = ' . (int) $id);
        } else {
            // Entry does not exist, create it
            $stats = new SedestralPostStats();
            $stats->post_id = (int) $post_id;
            $stats->count = 1;
            $stats->timestamp = $date;
            $stats->add();
        }
    }
}
