<?php
/**
 * 2024 Sedestral
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@sedestral.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    Sedestral <contact@sedestral.com>
 * @copyright 2024 Sedestral
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 * International Registered Trademark & Property of Sedestral
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

require_once _PS_MODULE_DIR_ . 'sedestral/classes/SedestralAbstractCustomAdminController.php';

class AdminSedestralSettingsController extends SedestralAbstractCustomAdminController
{
    public function __construct()
    {
        $this->bootstrap = true;
        $this->table = 'sedestral_settings';
        $this->className = 'Configuration';
        $this->context = Context::getContext();
        $this->domainTrans = 'adminsedestralsettingscontroller';

        parent::__construct();
    }

    public function initContent()
    {
        $this->display = 'edit';
        parent::initContent();
    }

    public function renderForm()
    {
        $output = '';

        if (Tools::isSubmit('submitSedestralConfig')) {
            // Retrieve and sanitize input values
            $base_route = Tools::getValue('SEDESTRAL_BASE_ROUTE');
            $base_route = trim($base_route);
            $update_route = false;

            // Validation de la route
            if (!$this->validateBaseRoute($base_route)) {
                $this->errors[] = $this->transCompatibility('Enter the base URL for your blog (e.g., "my-blog"). Use only letters, numbers, hyphens, and underscores.');
            } else {
                $base_route = preg_replace('/[^a-zA-Z0-9\-_]/', '', $base_route);
                if ($base_route !== Configuration::get('SEDESTRAL_BASE_ROUTE', null, null, null, 'blog')) {
                    Configuration::updateValue('SEDESTRAL_BASE_ROUTE', $base_route);
                    $update_route = true;
                }
            }

            $enable_blog = (int) Tools::getValue('SEDESTRAL_ENABLE_BLOG');
            $enable_blog_page = (int) Tools::getValue('SEDESTRAL_ENABLE_BLOG_PAGE');
            $enable_category_page = (int) Tools::getValue('SEDESTRAL_ENABLE_CATEGORY_PAGE');
            $enable_sitemap = (int) Tools::getValue('SEDESTRAL_ENABLE_SITEMAP');
            $enable_breadcrumb = (int) Tools::getValue('SEDESTRAL_ENABLE_BREADCRUMB');
            $enable_post_header = (int) Tools::getValue('SEDESTRAL_ENABLE_POST_HEADER');
            $enable_similar_posts = (int) Tools::getValue('SEDESTRAL_ENABLE_SIMILAR_POSTS');
            $enable_menu_categories = (int) Tools::getValue('SEDESTRAL_ENABLE_MENU_CATEGORIES');
            $enable_hook_home = (int) Tools::getValue('SEDESTRAL_ENABLE_HOOK_HOME');
            $enable_share_article = (int) Tools::getValue('SEDESTRAL_ENABLE_SHARE_ARTICLE');

            // Validation and saving logic here...
            if (Configuration::get('SEDESTRAL_ENABLE_SITEMAP', null, null, null, 0) != $enable_sitemap || ($enable_sitemap && $update_route)) {
                Tools::generateRobotsFile($enable_sitemap == 1);
            }

            Configuration::updateValue('SEDESTRAL_ENABLE_BLOG', $enable_blog);
            Configuration::updateValue('SEDESTRAL_ENABLE_BLOG_PAGE', $enable_blog_page);
            Configuration::updateValue('SEDESTRAL_ENABLE_CATEGORY_PAGE', $enable_category_page);
            Configuration::updateValue('SEDESTRAL_ENABLE_SITEMAP', $enable_sitemap);
            Configuration::updateValue('SEDESTRAL_ENABLE_BREADCRUMB', $enable_breadcrumb);
            Configuration::updateValue('SEDESTRAL_ENABLE_POST_HEADER', $enable_post_header);
            Configuration::updateValue('SEDESTRAL_ENABLE_SIMILAR_POSTS', $enable_similar_posts);
            Configuration::updateValue('SEDESTRAL_ENABLE_MENU_CATEGORIES', $enable_menu_categories);
            Configuration::updateValue('SEDESTRAL_ENABLE_HOOK_HOME', $enable_hook_home);
            Configuration::updateValue('SEDESTRAL_ENABLE_SHARE_ARTICLE', $enable_share_article);

            // Confirmation message
            $this->confirmations[] = $this->transCompatibility('Settings updated');
        }

        // Retrieve existing configuration values or set defaults
        $base_route = Configuration::get('SEDESTRAL_BASE_ROUTE', null, null, null, 'blog');
        $enable_blog = Configuration::get('SEDESTRAL_ENABLE_BLOG', null, null, null, 1);
        $enable_blog_page = Configuration::get('SEDESTRAL_ENABLE_BLOG_PAGE', null, null, null, 1);
        $enable_category_page = Configuration::get('SEDESTRAL_ENABLE_CATEGORY_PAGE', null, null, null, 1);
        $enable_sitemap = Configuration::get('SEDESTRAL_ENABLE_SITEMAP', null, null, null, 0);
        $enable_breadcrumb = Configuration::get('SEDESTRAL_ENABLE_BREADCRUMB', null, null, null, 1);
        $enable_post_header = Configuration::get('SEDESTRAL_ENABLE_POST_HEADER', null, null, null, 1);
        $enable_similar_posts = Configuration::get('SEDESTRAL_ENABLE_SIMILAR_POSTS', null, null, null, 1);
        $enable_menu_categories = Configuration::get('SEDESTRAL_ENABLE_MENU_CATEGORIES', null, null, null, 1);
        $enable_hook_home = Configuration::get('SEDESTRAL_ENABLE_HOOK_HOME', null, null, null, 0);
        $enable_share_article = Configuration::get('SEDESTRAL_ENABLE_SHARE_ARTICLE', null, null, null, 1);

        // Define the form structure
        $fields_form = [
            'form' => [
                'legend' => [
                    'title' => $this->transCompatibility('My Blog Settings'),
                    'icon' => 'icon-cogs',
                ],
                'input' => [
                    [
                        'type' => 'text',
                        'label' => $this->transCompatibility('Base Route'),
                        'name' => 'SEDESTRAL_BASE_ROUTE',
                        'size' => 20,
                        'required' => true,
                        'desc' => $this->transCompatibility('Enter the base URL for your blog (e.g., "my-blog"). Use only letters, numbers, hyphens, and underscores.'),
                    ],
                    [
                        'type' => 'switch',
                        'label' => $this->transCompatibility('Enable Blog'),
                        'name' => 'SEDESTRAL_ENABLE_BLOG',
                        'required' => true,
                        'is_bool' => true,
                        'values' => [
                            [
                                'id' => 'enable_blog_on',
                                'value' => 1,
                                'label' => $this->transCompatibility('Yes'),
                            ],
                            [
                                'id' => 'enable_blog_off',
                                'value' => 0,
                                'label' => $this->transCompatibility('No'),
                            ],
                        ],
                        'desc' => $this->transCompatibility('Enable or disable the blog. If disabled, all blog routes will be inactive.'),
                    ],
                    [
                        'type' => 'switch',
                        'label' => $this->transCompatibility('Enable Blog Page'),
                        'name' => 'SEDESTRAL_ENABLE_BLOG_PAGE',
                        'required' => true,
                        'is_bool' => true,
                        'values' => [
                            [
                                'id' => 'enable_blog_page_on',
                                'value' => 1,
                                'label' => $this->transCompatibility('Yes'),
                            ],
                            [
                                'id' => 'enable_blog_page_off',
                                'value' => 0,
                                'label' => $this->transCompatibility('No'),
                            ],
                        ],
                        'desc' => $this->transCompatibility('Enable or disable the blog page that displays all articles.'),
                    ],
                    [
                        'type' => 'switch',
                        'label' => $this->transCompatibility('Enable Category Page'),
                        'name' => 'SEDESTRAL_ENABLE_CATEGORY_PAGE',
                        'required' => true,
                        'is_bool' => true,
                        'values' => [
                            [
                                'id' => 'enable_category_page_on',
                                'value' => 1,
                                'label' => $this->transCompatibility('Yes'),
                            ],
                            [
                                'id' => 'enable_category_page_off',
                                'value' => 0,
                                'label' => $this->transCompatibility('No'),
                            ],
                        ],
                        'desc' => $this->transCompatibility('Enable or disable the category page that displays articles of a category.'),
                    ],
                    [
                        'type' => 'switch',
                        'label' => $this->transCompatibility('Enable Sitemap'),
                        'name' => 'SEDESTRAL_ENABLE_SITEMAP',
                        'required' => true,
                        'is_bool' => true,
                        'values' => [
                            [
                                'id' => 'enable_sitemap_on',
                                'value' => 1,
                                'label' => $this->transCompatibility('Yes'),
                            ],
                            [
                                'id' => 'enable_sitemap_off',
                                'value' => 0,
                                'label' => $this->transCompatibility('No'),
                            ],
                        ],
                        'desc' => $this->transCompatibility('Enable or disable the blog sitemap.'),
                    ],
                    [
                        'type' => 'switch',
                        'label' => $this->transCompatibility('Display Breadcrumb'),
                        'name' => 'SEDESTRAL_ENABLE_BREADCRUMB',
                        'required' => true,
                        'is_bool' => true,
                        'values' => [
                            [
                                'id' => 'enable_breadcrumb_on',
                                'value' => 1,
                                'label' => $this->transCompatibility('Yes'),
                            ],
                            [
                                'id' => 'enable_breadcrumb_off',
                                'value' => 0,
                                'label' => $this->transCompatibility('No'),
                            ],
                        ],
                        'desc' => $this->transCompatibility('Enable or disable the breadcrumb navigation at the top of the blog pages.'),
                    ],
                    [
                        'type' => 'switch',
                        'label' => $this->transCompatibility('Enable Post Header'), // Nouvelle section
                        'name' => 'SEDESTRAL_ENABLE_POST_HEADER',
                        'required' => true,
                        'is_bool' => true,
                        'values' => [
                            [
                                'id' => 'enable_post_header_on',
                                'value' => 1,
                                'label' => $this->transCompatibility('Yes'),
                            ],
                            [
                                'id' => 'enable_post_header_off',
                                'value' => 0,
                                'label' => $this->transCompatibility('No'),
                            ],
                        ],
                        'desc' => $this->transCompatibility('Enable or disable the header in the article presentation.'),
                    ],
                    [
                        'type' => 'switch', // New input for similar posts
                        'label' => $this->transCompatibility('Display Similar Posts'),
                        'name' => 'SEDESTRAL_ENABLE_SIMILAR_POSTS',
                        'required' => true,
                        'is_bool' => true,
                        'values' => [
                            [
                                'id' => 'enable_similar_posts_on',
                                'value' => 1,
                                'label' => $this->transCompatibility('Yes'),
                            ],
                            [
                                'id' => 'enable_similar_posts_off',
                                'value' => 0,
                                'label' => $this->transCompatibility('No'),
                            ],
                        ],
                        'desc' => $this->transCompatibility('Enable or disable the display of similar posts at the bottom of the article.'),
                    ],
                    [
                        'type' => 'switch', // New input for menu categories
                        'label' => $this->transCompatibility('Display Menu Categories'),
                        'name' => 'SEDESTRAL_ENABLE_MENU_CATEGORIES',
                        'required' => true,
                        'is_bool' => true,
                        'values' => [
                            [
                                'id' => 'enable_menu_categories_on',
                                'value' => 1,
                                'label' => $this->transCompatibility('Yes'),
                            ],
                            [
                                'id' => 'enable_menu_categories_off',
                                'value' => 0,
                                'label' => $this->transCompatibility('No'),
                            ],
                        ],
                        'desc' => $this->transCompatibility('Enable or disable the display of categories in the front.'),
                    ],
                    [
                        'type' => 'switch', // New input for hook home
                        'label' => $this->transCompatibility('Enable Hook Home'),
                        'name' => 'SEDESTRAL_ENABLE_HOOK_HOME',
                        'required' => true,
                        'is_bool' => true,
                        'values' => [
                            [
                                'id' => 'enable_hook_home_on',
                                'value' => 1,
                                'label' => $this->transCompatibility('Yes'),
                            ],
                            [
                                'id' => 'enable_hook_home_off',
                                'value' => 0,
                                'label' => $this->transCompatibility('No'),
                            ],
                        ],
                        'desc' => $this->transCompatibility('Enable or disable the display of the blog on the homepage.'),
                    ],
                    [
                        'type' => 'switch', // New input for share article
                        'label' => $this->transCompatibility('Enable Share Article'),
                        'name' => 'SEDESTRAL_ENABLE_SHARE_ARTICLE',
                        'required' => true,
                        'is_bool' => true,
                        'values' => [
                            [
                                'id' => 'enable_share_article_on',
                                'value' => 1,
                                'label' => $this->transCompatibility('Yes'),
                            ],
                            [
                                'id' => 'enable_share_article_off',
                                'value' => 0,
                                'label' => $this->transCompatibility('No'),
                            ],
                        ],
                        'desc' => $this->transCompatibility('Enable or disable the display of the share article block.'),
                    ],
                ],
                'submit' => [
                    'title' => $this->transCompatibility('Save'),
                ],
            ],
        ];

        // Generate the form
        $helper = new HelperForm();
        $helper->module = $this->module;
        $helper->name_controller = $this->controller_name;
        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitSedestralConfig';
        $helper->currentIndex = $this->context->link->getAdminLink($this->controller_name);
        $helper->token = Tools::getAdminTokenLite($this->controller_name);

        // Set form field values
        $helper->fields_value['SEDESTRAL_BASE_ROUTE'] = $base_route;
        $helper->fields_value['SEDESTRAL_ENABLE_BLOG'] = $enable_blog;
        $helper->fields_value['SEDESTRAL_ENABLE_BLOG_PAGE'] = $enable_blog_page;
        $helper->fields_value['SEDESTRAL_ENABLE_CATEGORY_PAGE'] = $enable_category_page;
        $helper->fields_value['SEDESTRAL_ENABLE_SITEMAP'] = $enable_sitemap;
        $helper->fields_value['SEDESTRAL_ENABLE_BREADCRUMB'] = $enable_breadcrumb;
        $helper->fields_value['SEDESTRAL_ENABLE_POST_HEADER'] = $enable_post_header;
        $helper->fields_value['SEDESTRAL_ENABLE_SIMILAR_POSTS'] = $enable_similar_posts;
        $helper->fields_value['SEDESTRAL_ENABLE_MENU_CATEGORIES'] = $enable_menu_categories;
        $helper->fields_value['SEDESTRAL_ENABLE_HOOK_HOME'] = $enable_hook_home;
        $helper->fields_value['SEDESTRAL_ENABLE_SHARE_ARTICLE'] = $enable_share_article;

        return $output . $helper->generateForm([$fields_form]);
    }

    private function validateBaseRoute($route)
    {
        return !empty($route) && preg_match('/^[a-zA-Z0-9\-_]+$/', $route);
    }
}
