<?php
/**
 * 2024 Sedestral
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@sedestral.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    Sedestral <contact@sedestral.com>
 * @copyright 2024 Sedestral
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 * International Registered Trademark & Property of Sedestral
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

require_once _PS_MODULE_DIR_ . 'sedestral/classes/SedestralAbstractCustomAdminController.php';

class AdminSedestralTokenController extends SedestralAbstractCustomAdminController
{
    public function __construct()
    {
        $this->bootstrap = true;
        $this->table = 'token';
        $this->className = 'Token';
        $this->lang = false;
        $this->domainTrans = 'adminsedestraltokencontroller';

        parent::__construct();

        // The Token object cannot be deleted
        $this->deleted = false;
    }

    public function initContent()
    {
        parent::initContent();

        // Prepare variables for the template
        $imagePath = $this->module->getPathUri() . 'views/img/sedestral_integration_v2.png';

        $description = $this->transCompatibility('Optimize your PrestaShop store\'s SEO with the integration of Sedestral.');
        $subDescription = $this->transCompatibility('To get started, register for free on');
        $formAction = self::$currentIndex . '&token=' . $this->token;
        $button_label = $this->transCompatibility('Create a token for Sedestral integration');
        $local_id_label = $this->transCompatibility('Your token to provide to Sedestral is');

        $this->context->smarty->assign([
            'imagePath' => $imagePath,
            'description' => $description,
            'subDescription' => $subDescription,
            'formAction' => $formAction,
            'button_label' => $button_label,
            'local_id_label' => $local_id_label,
        ]);

        if (Tools::getIsset('local_id')) {
            $this->context->smarty->assign('local_id', Tools::getValue('local_id'));
        }

        // Set the template
        $this->setTemplate('token.tpl');
    }

    public function postProcess()
    {
        if (Tools::isSubmit('createToken')) {
            // Create the Token object
            $token = new SedestralToken();

            // Generate local_id
            $token->local_id = $this->generateUniqueString();

            // Set date_created
            $token->date_created = date('Y-m-d H:i:s');

            // Save the object
            if ($token->add()) {
                // Redirect back with local_id displayed
                Tools::redirectAdmin(self::$currentIndex . '&local_id=' . $token->local_id . '&token=' . $this->token);
            } else {
                $this->errors[] = $this->transCompatibility('An error occurred while creating the token.');
            }
        }

        parent::postProcess();
    }

    public function processDelete()
    {
        // Override to prevent deletion
        $this->errors[] = $this->transCompatibility('This object cannot be deleted.');
        return false;
    }

    private function generateUniqueString($length = 32)
    {
        return bin2hex(random_bytes($length / 2));
    }
}
