<?php
/**
 * 2024 Sedestral
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@sedestral.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    Sedestral <contact@sedestral.com>
 * @copyright 2024 Sedestral
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 * International Registered Trademark & Property of Sedestral
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

require_once _PS_MODULE_DIR_ . 'sedestral/classes/SedestralBaseModuleFrontController.php';

class SedestralApiGoogleVerifyModuleFrontController extends SedestralBaseModuleFrontController
{
    public function __construct()
    {
        parent::__construct();
    }

    public function postProcess()
    {
        header('Content-Type: application/json');
        try {
            // Only accept POST requests
            if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
                http_response_code(400);
                exit(json_encode(['error' => 'Invalid request method.']));
            }

            // Get POST parameters
            $verificationKey = Tools::getValue('verification_key');
            $remoteId = Tools::getValue('remote_id');

            // Check if parameters are provided
            if (empty($verificationKey) || empty($remoteId)) {
                http_response_code(400);
                exit(json_encode(['error' => 'Missing parameters.']));
            }

            // Retrieve the token using remoteId
            $tokenObject = $this->getTokenByRemoteId($remoteId);
            if (!$tokenObject || empty($tokenObject->token)) {
                http_response_code(400);
                exit(json_encode(['error' => 'Invalid remoteId.']));
            }

            // Define the file path
            $fileName = pSQL($verificationKey) . '.html';
            $filePath = _PS_ROOT_DIR_ . DIRECTORY_SEPARATOR . $fileName;

            // Create the file content
            $fileContent = 'google-site-verification: ' . pSQL($verificationKey) . '.html';

            // Write to the file
            if (file_put_contents($filePath, $fileContent) === false) {
                http_response_code(500);
                exit(json_encode(['error' => 'Failed to create verification file.']));
            }

            // Return success response
            http_response_code(200);
            exit(json_encode(['status' => true, 'message' => 'Verification file created successfully.', 'file' => $fileName]));
        } catch (Exception $e) {
            // Log the exception as needed
            http_response_code(500);
            exit(json_encode(['error' => $e->getMessage()]));
        }
    }

    private function getTokenByRemoteId($remoteId)
    {
        // Implement the logic to get the SedestralToken object by remoteId
        $sql = new DbQuery();
        $sql->select('*');
        $sql->from('sedestral_token');
        $sql->where('remote_id = "' . pSQL($remoteId) . '"');

        $result = Db::getInstance()->getRow($sql);

        if ($result) {
            $token = new SedestralToken();
            $token->hydrate($result);

            return $token;
        } else {
            return false;
        }
    }
}
