<?php
/**
 * 2024 Sedestral
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@sedestral.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    Sedestral <contact@sedestral.com>
 * @copyright 2024 Sedestral
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 * International Registered Trademark & Property of Sedestral
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

require_once _PS_MODULE_DIR_ . 'sedestral/classes/SedestralBaseModuleFrontController.php';

class SedestralCategoryModuleFrontController extends SedestralBaseModuleFrontController
{
    public function initContent()
    {
        $this->domainTrans = 'category';

        parent::initContent();

        $id_lang = $this->context->language->id;
        $category_rewrite = Tools::getValue('category_rewrite');

        if (!$category_rewrite) {
            // Rediriger vers la page blog si aucune catégorie n'est spécifiée
            Tools::redirect($this->context->link->getModuleLink('sedestral', 'blog', [], true, $id_lang));
        }

        // Récupérer la catégorie basée sur la réécriture
        $category = new SedestralCategory();
        $category = $category->getByRoute($category_rewrite, $id_lang);
        if (!$category) {
            // Afficher une page 404 si la catégorie n'existe pas ou n'est pas publiée
            header($_SERVER['SERVER_PROTOCOL'] . ' 404 Not Found');
            $this->setTemplate('errors/404.tpl');

            return;
        }

        // Vérification et redirection de la langue
        $this->checkAndRedirectLanguage();

        // Pagination
        $whereClause = 'p.id_lang = ' . pSQL($id_lang) . ' AND p.id_sedestral_category = ' . pSQL($category->id_sedestral_category);
        $pagination = $this->getPagination($whereClause);
        $page = $pagination['page'];
        $total_pages = $pagination['total_pages'];
        $offset = $pagination['offset'];

        // Récupérer les articles de la catégorie
        $results = $this->fetchPosts($whereClause, $offset);

        $posts = [];
        foreach ($results as $row) {
            $post = new SedestralPost();
            $post->hydrate($row);
            $post->cover_thumbnail_url = $post->getCoverThumbnailUrl($this->context, $post->cover, 'url');
            $post->loadImages($this->context);
            $post->total_route = $this->context->link->getModuleLink(
                'sedestral',
                'post',
                [
                    'category_rewrite' => $row['category_route'],
                    'post_rewrite' => $post->route,
                ]
            );
            $posts[] = $post;
        }

        // Construction du fil d'Ariane avec une étape supplémentaire pour la catégorie
        $this->buildBreadcrumb([
            [
                'count' => 3,
                'title' => $category->title,
                'url' => '',
            ],
        ]);

        // Assignation des variables au template
        $this->context->smarty->assign([
            'current_category_id' => $category->id_sedestral_category,
            'categories' => $this->getPublishedCategories(),
            'posts' => $posts,
            'current_page' => $page,
            'total_pages' => $total_pages,
            'module_link' => $this->context->link->getModuleLink('sedestral', 'category', ['category_rewrite' => $category->route], true, $id_lang),
            'category_title' => $category->title,
        ]);

        // Assignation des métadonnées
        $this->assignPageMeta([
            'title' => $category->title . ($page != '1' ? ' - ' . $page : ''),
            'description' => $category->snippet,
            'keywords' => '',
        ]);

        // Définir le template à utiliser
        $this->setTemplate('module:sedestral/views/templates/front/category.tpl');
    }
}
