<?php
/**
 * 2024 Sedestral
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@sedestral.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    Sedestral <contact@sedestral.com>
 * @copyright 2024 Sedestral
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 * International Registered Trademark & Property of Sedestral
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

class SedestralSitemapModuleFrontController extends ModuleFrontController
{
    public function initContent()
    {
        header('Content-Type: application/xml; charset=utf-8');

        // Début du document XML
        echo '<?xml version="1.0" encoding="UTF-8"?>';
        echo '<urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9">';

        // 1. Récupérer toutes les langues actives
        $languages = Language::getLanguages(false);

        foreach ($languages as $language) {
            $id_lang = (int) $language['id_lang'];

            $blogUrl = $this->context->link->getModuleLink(
                'sedestral',
                'blog',
                [],
                true,
                $id_lang
            );

            echo '<url>';
            echo '<loc>' . htmlspecialchars($blogUrl) . '</loc>';
            echo '<changefreq>weekly</changefreq>';
            echo '<priority>1.0</priority>';
            echo '</url>';

            $sqlCategories = '
                SELECT c.*
                FROM ' . _DB_PREFIX_ . 'sedestral_category c
                WHERE c.state = "publish"
                AND c.id_lang = ' . $id_lang . '
            ';
            $categories = Db::getInstance()->executeS($sqlCategories);

            foreach ($categories as $categoryData) {
                $category = new SedestralCategory();
                $category->hydrate($categoryData);

                $categoryUrl = $this->context->link->getModuleLink(
                    'sedestral',
                    'category',
                    ['category_rewrite' => $category->route],
                    true,
                    $id_lang
                );

                echo '<url>';
                echo '<loc>' . htmlspecialchars($categoryUrl) . '</loc>';
                echo '<changefreq>weekly</changefreq>';
                echo '<priority>' . htmlspecialchars($category->sitemap_priority) . '</priority>';
                echo '</url>';
            }

            $sqlPosts = '
                SELECT p.*, c.route AS category_route
                FROM ' . _DB_PREFIX_ . 'sedestral_post p
                LEFT JOIN ' . _DB_PREFIX_ . 'sedestral_category c 
                    ON (p.id_sedestral_category = c.id_sedestral_category)
                WHERE p.state = "publish"
                  AND c.state = "publish"
                  AND p.id_lang = ' . $id_lang . '
                  AND p.date_published <= NOW()
            ';
            $posts = Db::getInstance()->executeS($sqlPosts);

            foreach ($posts as $postData) {
                $post = new SedestralPost();
                $post->hydrate($postData);

                $postUrl = $this->context->link->getModuleLink(
                    'sedestral',
                    'post',
                    ['category_rewrite' => $postData['category_route'], 'post_rewrite' => $post->route],
                    true,
                    $id_lang
                );

                echo '<url>';
                echo '<loc>' . htmlspecialchars($postUrl) . '</loc>';
                echo '<changefreq>weekly</changefreq>';
                echo '<priority>' . htmlspecialchars($post->sitemap_priority) . '</priority>';
                echo '</url>';
            }
        }

        // Fin du document XML
        echo '</urlset>';
        exit;
    }
}
