<?php
/**
 * 2024 Sedestral
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@sedestral.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    Sedestral <contact@sedestral.com>
 * @copyright 2024 Sedestral
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 * International Registered Trademark & Property of Sedestral
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

require_once _PS_MODULE_DIR_ . 'sedestral/classes/SedestralPost.php';
require_once _PS_MODULE_DIR_ . 'sedestral/classes/SedestralCategory.php';
require_once _PS_MODULE_DIR_ . 'sedestral/classes/SedestralToken.php';
require_once _PS_MODULE_DIR_ . 'sedestral/classes/SedestralPostStats.php';

class Sedestral extends Module
{
    public function __construct()
    {
        $this->name = 'sedestral';
        $this->tab = 'front_office_features';
        $this->version = '1.0.25';
        $this->author = 'Sedestral';
        $this->need_instance = 0;

        $this->bootstrap = true;

        $this->module_key = '995d5af9b55a869963134ede288d837c';

        parent::__construct();

        $this->displayName = $this->transCompatibility('SEO Optimization');
        $this->description = $this->transCompatibility('All-in-one solution to optimize the SEO of your product pages, product categories, and blog articles with our software available on sedestral.com');

        $this->ps_versions_compliancy = ['min' => '1.7', 'max' => _PS_VERSION_];

        $this->maybeNotifyVersion();
    }

    public function getContent()
    {
        // Redirige vers une route spécifique
        Tools::redirectAdmin($this->context->link->getAdminLink('AdminSedestralSettings'));
    }

    public function install()
    {
        // Définir les valeurs de configuration par défaut à '1' (activé)
        Configuration::updateValue('SEDESTRAL_BASE_ROUTE', 'blog');
        Configuration::updateValue('SEDESTRAL_ENABLE_BLOG', 1);
        Configuration::updateValue('SEDESTRAL_ENABLE_BLOG_PAGE', 1);
        Configuration::updateValue('SEDESTRAL_ENABLE_CATEGORY_PAGE', 1);
        Configuration::updateValue('SEDESTRAL_ENABLE_SITEMAP', 0);
        Configuration::updateValue('SEDESTRAL_ENABLE_BREADCRUMB', 1);
        Configuration::updateValue('SEDESTRAL_ENABLE_POST_HEADER', 1);
        Configuration::updateValue('SEDESTRAL_ENABLE_SIMILAR_POSTS', 1);

        if (!parent::install()
            || !$this->installTab('DEFAULT', 'AdminSedestral', $this->transCompatibility('SEO Optimization'))
            || !$this->installTab('AdminSedestral', 'AdminSedestralPosts', $this->transCompatibility('Posts'))
            || !$this->installTab('AdminSedestral', 'AdminSedestralCategories', $this->transCompatibility('Categories'))
            || !$this->installTab('AdminSedestral', 'AdminSedestralSettings', $this->transCompatibility('Settings'))
            || !$this->installTab('AdminSedestral', 'AdminSedestralToken', $this->transCompatibility('Integration'))
            || !$this->registerHook('moduleRoutes')
            || !$this->registerHook('actionAdminMetaAfterWriteRobotsFile')
            || !$this->registerHook('actionFrontControllerSetMedia')
            || !$this->registerHook('displayHome')
        ) {
            return false;
        }

        if (!$this->installSql()) {
            return false;
        }

        $sourceDir = _PS_IMG_DIR_ . 'modules/myblog/';
        $destinationDir = _PS_IMG_DIR_ . 'modules/sedestral/';
        $this->copyDirectoryContent($sourceDir, $destinationDir);

        return true;
    }

    public function uninstall()
    {
        Configuration::deleteByName('SEDESTRAL_BASE_ROUTE');
        Configuration::deleteByName('SEDESTRAL_ENABLE_BLOG');
        Configuration::deleteByName('SEDESTRAL_ENABLE_BLOG_PAGE');
        Configuration::deleteByName('SEDESTRAL_ENABLE_CATEGORY_PAGE');
        Configuration::deleteByName('SEDESTRAL_ENABLE_SITEMAP');
        Configuration::deleteByName('SEDESTRAL_ENABLE_SITEMAP');
        Configuration::deleteByName('SEDESTRAL_ENABLE_BREADCRUMB');
        Configuration::deleteByName('SEDESTRAL_ENABLE_POST_HEADER');
        Configuration::deleteByName('SEDESTRAL_ENABLE_SIMILAR_POSTS');

        $this->uninstallTab('AdminSedestralToken');
        $this->uninstallTab('AdminSedestralSettings');
        $this->uninstallTab('AdminSedestralCategories');
        $this->uninstallTab('AdminSedestralPosts');
        $this->uninstallTab('AdminSedestral');

        $this->uninstallTab('AdminMyBlogToken');
        $this->uninstallTab('AdminMyBlogSettings');
        $this->uninstallTab('AdminMyBlogCategories');
        $this->uninstallTab('AdminMyBlogPosts');
        $this->uninstallTab('AdminMyBlog');

        Tools::generateRobotsFile();

        // Exécuter le script SQL de désinstallation
        if (!$this->uninstallSql()) {
            return false;
        }

        return parent::uninstall();
    }

    private function installSql()
    {
        $sql = [];

        // Stockage de la vérification des tables dans des variables booléennes
        $tablePostExists = count(Db::getInstance()->executeS("SHOW TABLES LIKE '" . _DB_PREFIX_ . "myblog_post'")) > 0
            && count(Db::getInstance()->executeS("SHOW TABLES LIKE '" . _DB_PREFIX_ . "sedestral_post'")) === 0;

        $tableCategoryExists = count(Db::getInstance()->executeS("SHOW TABLES LIKE '" . _DB_PREFIX_ . "myblog_category'")) > 0
            && count(Db::getInstance()->executeS("SHOW TABLES LIKE '" . _DB_PREFIX_ . "sedestral_category'")) === 0;

        $tableTokenExists = count(Db::getInstance()->executeS("SHOW TABLES LIKE '" . _DB_PREFIX_ . "myblog_token'")) > 0
            && count(Db::getInstance()->executeS("SHOW TABLES LIKE '" . _DB_PREFIX_ . "sedestral_token'")) === 0;

        $tablePostStatsExists = count(Db::getInstance()->executeS("SHOW TABLES LIKE '" . _DB_PREFIX_ . "myblog_post_stats'")) > 0
            && count(Db::getInstance()->executeS("SHOW TABLES LIKE '" . _DB_PREFIX_ . "sedestral_post_stats'")) === 0;

        // Étape 1 : Création des nouvelles tables avec copie des données
        if ($tablePostExists) {
            $sql[] = 'CREATE TABLE ' . _DB_PREFIX_ . 'sedestral_post AS SELECT * FROM ' . _DB_PREFIX_ . 'myblog_post;';
            $sql[] = 'ALTER TABLE `' . _DB_PREFIX_ . 'sedestral_post`
              CHANGE `id_myblog_post` `id_sedestral_post` INT(11) NOT NULL,
              CHANGE `id_myblog_category` `id_sedestral_category` INT(11) NOT NULL;';
            $sql[] = 'ALTER TABLE `' . _DB_PREFIX_ . 'sedestral_post`
              MODIFY `id_sedestral_post` INT(11) NOT NULL AUTO_INCREMENT,
              ADD PRIMARY KEY (`id_sedestral_post`);';
        } else {
            $sql[] = 'CREATE TABLE IF NOT EXISTS `' . _DB_PREFIX_ . 'sedestral_post` (
        `id_sedestral_post` INT(11) NOT NULL AUTO_INCREMENT,
        `id_sedestral_category` INT(11) NOT NULL,
        `id_lang` INT(11) NOT NULL,
        `author` VARCHAR(255),
        `cover` VARCHAR(255),
        `state` VARCHAR(10) NOT NULL,
        `title` VARCHAR(255) NOT NULL,
        `snippet` VARCHAR(500) NOT NULL,
        `content` TEXT NOT NULL,
        `keywords` VARCHAR(255),
        `route` VARCHAR(255) NOT NULL,
        `sitemap_priority` FLOAT NOT NULL,
        `date_published` DATETIME NOT NULL, 
        PRIMARY KEY (`id_sedestral_post`),
        UNIQUE KEY `route_lang_unique` (`route`, `id_lang`),
        INDEX `idx_id_sedestral_category` (`id_sedestral_category`),
        INDEX `idx_id_lang` (`id_lang`),
        INDEX `idx_route` (`route`)
    ) ENGINE=' . _MYSQL_ENGINE_ . ' DEFAULT CHARSET=utf8;';
        }

        if ($tableCategoryExists) {
            $sql[] = 'CREATE TABLE ' . _DB_PREFIX_ . 'sedestral_category AS SELECT * FROM ' . _DB_PREFIX_ . 'myblog_category;';
            $sql[] = 'ALTER TABLE `' . _DB_PREFIX_ . 'sedestral_category`
              CHANGE `id_myblog_category` `id_sedestral_category` INT(11) NOT NULL;';
            $sql[] = 'ALTER TABLE `' . _DB_PREFIX_ . 'sedestral_category`
              MODIFY `id_sedestral_category` INT(11) NOT NULL AUTO_INCREMENT,
              ADD PRIMARY KEY (`id_sedestral_category`);';
        } else {
            $sql[] = 'CREATE TABLE IF NOT EXISTS `' . _DB_PREFIX_ . 'sedestral_category` (
        `id_sedestral_category` INT(11) NOT NULL AUTO_INCREMENT,
        `id_lang` INT(11) NOT NULL,
        `state` VARCHAR(10),
        `title` VARCHAR(255) NOT NULL,
        `snippet` VARCHAR(500),
        `route` VARCHAR(255) NOT NULL,
        `sitemap_priority` FLOAT NOT NULL DEFAULT 0.5,
        PRIMARY KEY (`id_sedestral_category`),
        UNIQUE KEY `route_lang_unique` (`route`, `id_lang`),
        INDEX `idx_id_lang` (`id_lang`),
        INDEX `idx_route` (`route`)
    ) ENGINE=' . _MYSQL_ENGINE_ . ' DEFAULT CHARSET=utf8;';
        }

        if ($tableTokenExists) {
            $sql[] = 'CREATE TABLE ' . _DB_PREFIX_ . 'sedestral_token AS SELECT * FROM ' . _DB_PREFIX_ . 'myblog_token;';
        } else {
            $sql[] = 'CREATE TABLE IF NOT EXISTS `' . _DB_PREFIX_ . 'sedestral_token` (
        `id_token` INT(11) NOT NULL AUTO_INCREMENT,
        `date_created` DATETIME NULL,
        `remote_id` VARCHAR(255) NULL,
        `local_id` VARCHAR(255) NULL,
        `api_token` VARCHAR(255) NULL,
        `token` VARCHAR(255) NULL,
        PRIMARY KEY (`id_token`),
        INDEX `idx_remote_id` (`remote_id`),
        INDEX `idx_local_id` (`local_id`),
        INDEX `idx_api_token` (`api_token`),
        INDEX `idx_token` (`token`)
        ) ENGINE=' . _MYSQL_ENGINE_ . ' DEFAULT CHARSET=utf8;';
        }

        if ($tablePostStatsExists) {
            $sql[] = 'CREATE TABLE ' . _DB_PREFIX_ . 'sedestral_post_stats AS SELECT * FROM ' . _DB_PREFIX_ . 'myblog_post_stats;';
        } else {
            $sql[] = 'CREATE TABLE IF NOT EXISTS `' . _DB_PREFIX_ . 'sedestral_post_stats` (
            `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
            `post_id` INT UNSIGNED NOT NULL,
            `count` INT UNSIGNED NOT NULL DEFAULT 0,
            `timestamp` DATETIME NOT NULL,
            PRIMARY KEY (`id`),
            UNIQUE INDEX `post_date` (`post_id`, `timestamp`),
            INDEX `post_id` (`post_id`),
            INDEX `timestamp` (`timestamp`)
        ) ENGINE=' . _MYSQL_ENGINE_ . ' DEFAULT CHARSET=utf8';
        }

        foreach ($sql as $query) {
            if (!Db::getInstance()->execute($query)) {
                return false;
            }
        }

        return true;
    }

    private function uninstallSql()
    {
        $sql = [];

        // Liste des requêtes SQL à exécuter
        $sql[] = 'DROP TABLE IF EXISTS `' . _DB_PREFIX_ . 'sedestral_post`;';
        $sql[] = 'DROP TABLE IF EXISTS `' . _DB_PREFIX_ . 'sedestral_category`;';
        $sql[] = 'DROP TABLE IF EXISTS `' . _DB_PREFIX_ . 'sedestral_token`;';
        $sql[] = 'DROP TABLE IF EXISTS `' . _DB_PREFIX_ . 'sedestral_post_stats`';

        foreach ($sql as $query) {
            if (!Db::getInstance()->execute($query)) {
                return false;
            }
        }

        return true;
    }

    private function installTab($parent_class_name, $class_name, $tab_name)
    {
        $tab = new Tab();
        $tab->active = 1;
        $tab->class_name = $class_name;
        $tab->module = $this->name;

        // Si $parent_class_name est 0, l'onglet sera au niveau racine
        $tab->id_parent = (int) Tab::getIdFromClassName($parent_class_name);
        if (!$tab->id_parent) {
            $tab->id_parent = 0;
        }

        foreach (Language::getLanguages(true) as $lang) {
            $tab->name[$lang['id_lang']] = $tab_name;
        }

        return $tab->add();
    }

    private function uninstallTab($class_name)
    {
        $id_tab = Tab::getIdFromClassName($class_name);
        if ($id_tab) {
            $tab = new Tab($id_tab);

            return $tab->delete();
        }

        return false;
    }

    public function hookDisplayHome($params)
    {
        $posts = [];
        $enable_hook_home = Configuration::get('SEDESTRAL_ENABLE_HOOK_HOME', null, null, null, 0);

        if ($enable_hook_home) {
            // ID de la langue active
            $id_lang = (int) $this->context->language->id;

            // Clause WHERE pour filtrer les articles publiés
            $whereClause = 'p.state = "publish" AND p.id_lang = ' . $id_lang;

            // Offset à 0 pour afficher les derniers articles
            $offset = 0;

            // Appel à la méthode fetchPosts pour récupérer les articles
            $results = SedestralPost::fetchPosts($whereClause, $offset, 2);

            foreach ($results as $row) {
                $post = new SedestralPost();
                $post->hydrate($row);
                $post->cover_thumbnail_url = $post->getCoverThumbnailUrl($this->context, $post->cover, 'url');
                $post->loadImages($this->context);
                $post->total_route = $this->context->link->getModuleLink(
                    'sedestral',
                    'post',
                    [
                        'category_rewrite' => $row['category_route'],
                        'post_rewrite' => $post->route,
                    ]
                );
                $posts[] = $post;
            }
        }

        // Assigner les articles au templates
        $this->context->smarty->assign([
            'latest_posts' => $this->transCompatibility('Latest Blog Posts'),
            'view_all_posts' => $this->transCompatibility('View All Posts'),
            'articles' => $posts,
            'blog_link' => $this->context->link->getModuleLink('sedestral', 'blog'),
        ]);

        // Retourner le rendu du template
        return $this->display(__FILE__, 'views/templates/front/displayHome.tpl');
    }

    public function hookModuleRoutes($params)
    {
        $enable_blog = Configuration::get('SEDESTRAL_ENABLE_BLOG', null, null, null, 1);
        if (!$enable_blog) {
            return [];
        }

        $base_route = $this->getBaseRoute();

        $routes = [];

        $enable_blog_page = Configuration::get('SEDESTRAL_ENABLE_BLOG_PAGE', null, null, null, 1);
        $enable_category_page = Configuration::get('SEDESTRAL_ENABLE_CATEGORY_PAGE', null, null, null, 1);
        $enable_site_map = Configuration::get('SEDESTRAL_ENABLE_SITEMAP', null, null, null, 0);

        // Common language parameter
        $language_param = [
            'lang' => ['regexp' => '[a-z]{2}', 'param' => 'lang'],
        ];

        if ($enable_blog_page) {
            $routes['module-sedestral-blog'] = [
                'controller' => 'blog',
                'rule' => $base_route,
                'keywords' => [],
                'params' => [
                    'fc' => 'module',
                    'module' => 'sedestral',
                ],
            ];
        }

        if ($enable_category_page) {
            $routes['module-sedestral-category'] = [
                'controller' => 'category',
                'rule' => $base_route . '/{category_rewrite}',
                'keywords' => [
                    'category_rewrite' => ['regexp' => '[_a-zA-Z0-9-\pL]*', 'param' => 'category_rewrite'],
                ],
                'params' => [
                    'fc' => 'module',
                    'module' => 'sedestral',
                ],
            ];
        }

        // Always include the post route if the blog is enabled
        $routes['module-sedestral-post'] = [
            'controller' => 'post',
            'rule' => $base_route . '/{category_rewrite}/{post_rewrite}',
            'keywords' => [
                'category_rewrite' => ['regexp' => '[_a-zA-Z0-9-\pL]*', 'param' => 'category_rewrite'],
                'post_rewrite' => ['regexp' => '[_a-zA-Z0-9-\pL]*', 'param' => 'post_rewrite'],
            ],
            'params' => [
                'fc' => 'module',
                'module' => 'sedestral',
            ],
        ];

        if ($enable_site_map) {
            $routes['module-sedestral-sitemap'] = [
                'controller' => 'sitemap',
                'rule' => $base_route . '/sitemap.xml',
                'keywords' => $language_param,
                'params' => [
                    'fc' => 'module',
                    'module' => 'sedestral',
                ],
            ];
        }

        $routes['module-sedestral-api-register'] = [
            'controller' => 'apiRegister',
            'rule' => 'myblog/api/register',
            'keywords' => [],
            'params' => [
                'fc' => 'module',
                'module' => 'sedestral',
            ],
        ];

        $routes['module-sedestral-api-publish'] = [
            'controller' => 'apiPublish',
            'rule' => 'myblog/api/publish',
            'keywords' => [],
            'params' => [
                'fc' => 'module',
                'module' => 'sedestral',
            ],
        ];

        $routes['module-sedestral-api-check-post'] = [
            'controller' => 'apiCheckPost',
            'rule' => 'myblog/api/check-post',
            'keywords' => [],
            'params' => [
                'fc' => 'module',
                'module' => 'sedestral',
            ],
        ];

        $routes['module-sedestral-api-get-data'] = [
            'controller' => 'apiGetData',
            'rule' => 'myblog/api/get-data',
            'keywords' => [],
            'params' => [
                'fc' => 'module',
                'module' => 'sedestral',
            ],
        ];

        $routes['module-sedestral-api-get-datas'] = [
            'controller' => 'apiGetDatas',
            'rule' => 'myblog/api/get-datas',
            'keywords' => [],
            'params' => [
                'fc' => 'module',
                'module' => 'sedestral',
            ],
        ];

        $routes['module-sedestral-api-post-data'] = [
            'controller' => 'apiPostData',
            'rule' => 'myblog/api/post-data',
            'keywords' => [],
            'params' => [
                'fc' => 'module',
                'module' => 'sedestral',
            ],
        ];

        $routes['module-sedestral-api-google-verify'] = [
            'controller' => 'apiGoogleVerify',
            'rule' => 'myblog/api/google-verify',
            'keywords' => [],
            'params' => [
                'fc' => 'module',
                'module' => 'sedestral',
            ],
        ];

        $routes['module-sedestral-sitemap-fixed'] = [
            'controller' => 'sitemap',
            'rule' => 'myblog/api/sitemap.xml',
            'keywords' => [],
            'params' => [
                'fc' => 'module',
                'module' => 'sedestral',
            ],
        ];

        return $routes;
    }

    public function hookActionFrontControllerSetMedia()
    {
        $this->context->controller->registerStylesheet(
            'module-sedestral-css', // Identifiant unique pour votre CSS
            $this->_path . 'views/css/sedestral.css', // Chemin vers votre fichier CSS
            [
                'media' => 'all', // Type de média, par exemple 'all', 'screen', etc.
                'priority' => 50, // Priorité de chargement (optionnel)
            ]
        );
    }

    public function hookActionAdminMetaAfterWriteRobotsFile($params)
    {
        $domain = Tools::getShopDomainSsl(true, true);
        $base_route = $this->getBaseRoute();
        $write_fd = $params['write_fd'];
        fwrite($write_fd, "# Sitemap Sedestral Module\n");
        fwrite($write_fd, 'Sitemap: ' . $domain . '/' . $base_route . "/sitemap.xml\n\n");
    }

    public function getBaseRoute()
    {
        return Configuration::get('SEDESTRAL_BASE_ROUTE', null, null, null, 'blog');
    }

    public function copyDirectoryContent($sourceDir, $destinationDir)
    {
        // Check if source directory exists
        if (!is_dir($sourceDir)) {
            return false;
        }

        // Create destination directory if it does not exist
        if (!is_dir($destinationDir)) {
            if (!mkdir($destinationDir, 0755, true)) {
                return false;
            }
        }

        // Open the source directory
        $dirHandle = opendir($sourceDir);
        if (!$dirHandle) {
            return false;
        }

        // Loop through the files and directories in the source directory
        while (($item = readdir($dirHandle)) !== false) {
            if ($item === '.' || $item === '..') {
                continue;
            }

            $sourcePath = $sourceDir . DIRECTORY_SEPARATOR . $item;
            $destinationPath = $destinationDir . DIRECTORY_SEPARATOR . $item;

            // If it's a directory, recursively copy its contents
            if (is_dir($sourcePath)) {
                if (!$this->copyDirectoryContent($sourcePath, $destinationPath)) {
                    closedir($dirHandle);
                    return false;
                }
            } else {
                // If it's a file, copy it
                if (!copy($sourcePath, $destinationPath)) {
                    closedir($dirHandle);
                    return false;
                }
            }
        }

        closedir($dirHandle);
        return true;
    }

    protected function transCompatibility($key)
    {
        // Depuis PrestaShop 1.7.6, on peut utiliser ->trans()
        // En dessous, on utilise ->l()
        if (version_compare(_PS_VERSION_, '1.7.6.0', '>=')) {
            return $this->trans($key, [], 'Modules.sedestral');
        }

        // Sur les anciennes versions, la méthode trans() n’existe pas,
        // on se contente de ->l() (qui ne prend en charge que la clé brute).
        // On ne peut pas gérer le domain ou les params ici.
        return $this->transCompatibility($key);
    }

    private function maybeNotifyVersion()
    {
        $key = $this->name . '_sent_version';
        $sentValue = Configuration::get($key);

        if ($sentValue !== $this->version) {
            $this->notifyVersion();
            Configuration::updateValue($key, $this->version);
        }
    }

    private function notifyVersion()
    {
        $ch = null;
        try {
            $tokens = SedestralToken::getAllRemoteIds();
            if (empty($tokens)) {
                return;
            }

            $url = 'https://panel.sedestral.com/community/partner/updateVersion';
            $body = ['tokens' => implode(',', $tokens), 'version' => $this->version];

            $ch = curl_init($url);
            if ($ch === false) {
                return;
            }
            curl_setopt_array($ch, [
                CURLOPT_POST => true,
                CURLOPT_POSTFIELDS => http_build_query($body, '', '&'),
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_HTTPHEADER => ['Accept: application/json', 'Content-Type: application/x-www-form-urlencoded'],
                CURLOPT_TIMEOUT => 5,
            ]);
            curl_exec($ch);
        } catch (Exception $e) {
            PrestaShopLogger::addLog('Sedestral version notification failed: ' . $e->getMessage(), 3);
        }
        if (is_resource($ch)) {
            curl_close($ch);
        }
    }
}
