{**
 * 2024 Sedestral
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@sedestral.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    Sedestral <contact@sedestral.com>
 * @copyright 2024 Sedestral
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 * International Registered Trademark & Property of Sedestral
*}
<div class="panel">

    <div style="text-align: right; margin-bottom: 10px;">
        <a href="{$back_url|escape:'htmlall':'UTF-8'}" class="btn btn-default">
            <i class="icon-arrow-left"></i> {$back_label|escape:'htmlall':'UTF-8'}
        </a>
    </div>

    <h1>
        {if isset($post)}
            {$post->title|escape:'htmlall':'UTF-8'}
        {else}
            {$global_stats_title_label|escape:'htmlall':'UTF-8'}
        {/if}
    </h1>

    <h2>{$last_30_days_label|escape:'htmlall':'UTF-8'}</h2>
    {if $hasDailyData}
        <div id="dailyChart" style="width: 100%; height: 500px;"></div>
    {else}
        <p>{$no_data_label|escape:'htmlall':'UTF-8'}</p>
    {/if}

    <h2>{$last_12_months_label|escape:'htmlall':'UTF-8'}</h2>
    {if $hasMonthlyData}
        <div id="monthlyChart" style="width: 100%; height: 500px;"></div>
    {else}
        <p>{$no_data_label|escape:'htmlall':'UTF-8'}</p>
    {/if}
</div>

{literal}
<script type="text/javascript">
    // Load the Visualization API and the corechart package.
    google.charts.load('current', {'packages':['corechart']});

    // Set a callback to run when the Google Visualization API is loaded.
    google.charts.setOnLoadCallback(drawCharts);

    function drawCharts() {
        {/literal}
        {if $hasDailyData}
        {literal}
        // Prepare daily data
        var statsDataDaily = JSON.parse({/literal}{$statsDataDaily|json_encode}{literal});

        var dailyDataArray = [
            ['Date', '{/literal}{$views_label|escape:"javascript":"UTF-8"}{literal}']
        ];

        var maxDailyValue = 0;

        for (var date in statsDataDaily) {
            var value = statsDataDaily[date];
            dailyDataArray.push([date, value]);
            if (value > maxDailyValue) {
                maxDailyValue = value;
            }
        }

        var dailyData = google.visualization.arrayToDataTable(dailyDataArray);

        // Generate integer ticks for vAxis
        var dailyTicks = [];
        for (var i = 0; i <= maxDailyValue + 1; i++) {
            dailyTicks.push(i);
        }

        var dailyOptions = {
            title: '{/literal}{$last_30_days_label|escape:"javascript":"UTF-8"}{literal}',
            hAxis: { title: '{/literal}{$date_label|escape:"javascript":"UTF-8"}{literal}' },
            vAxis: {
                title: '{/literal}{$views_label|escape:"javascript":"UTF-8"}{literal}',
                minValue: 0,
                format: '0',
                ticks: dailyTicks
            },
            legend: { position: 'none' },
            bar: { groupWidth: '75%' },
            chartArea: { width: '80%', height: '70%' }
        };

        var dailyChart = new google.visualization.ColumnChart(document.getElementById('dailyChart'));
        dailyChart.draw(dailyData, dailyOptions);
        {/literal}
        {/if}

        {if $hasMonthlyData}
        {literal}
        // Prepare monthly data
        var statsDataMonthly = JSON.parse({/literal}{$statsDataMonthly|json_encode}{literal});

        var monthlyDataArray = [['Month', '{/literal}{$views_label|escape:"javascript":"UTF-8"}{literal}']];

        var maxMonthlyValue = 0;

        for (var month in statsDataMonthly) {
            var value = statsDataMonthly[month];
            monthlyDataArray.push([month, value]);
            if (value > maxMonthlyValue) {
                maxMonthlyValue = value;
            }
        }

        var monthlyData = google.visualization.arrayToDataTable(monthlyDataArray);

        // Generate integer ticks for vAxis
        var monthlyTicks = [];
        for (var i = 0; i <= maxMonthlyValue + 1; i++) {
            monthlyTicks.push(i);
        }

        var monthlyOptions = {
            title: '{/literal}{$last_12_months_label|escape:"javascript":"UTF-8"}{literal}',
            hAxis: { title: '{/literal}{$month_label|escape:"javascript":"UTF-8"}{literal}' },
            vAxis: {
                title: '{/literal}{$views_label|escape:"javascript":"UTF-8"}{literal}',
                minValue: 0,
                format: '0',
                ticks: monthlyTicks
            },
            legend: { position: 'none' },
            bar: { groupWidth: '75%' },
            chartArea: { width: '80%', height: '70%' }
        };

        var monthlyChart = new google.visualization.ColumnChart(document.getElementById('monthlyChart'));
        monthlyChart.draw(monthlyData, monthlyOptions);
        {/literal}
        {/if}
        {literal}
    }
</script>
{/literal}
