{**
 * 2024 Sedestral
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@sedestral.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    Sedestral <contact@sedestral.com>
 * @copyright 2024 Sedestral
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 * International Registered Trademark & Property of Sedestral
*}
{extends file='page.tpl'}

{block name='page_content'}
    <div class="blog-container">
        {if $categories|@count > 0}
        <aside class="blog-menu">
            <ul>
                {foreach from=$categories item=category}
                    <li>
                        <a href="{$category.link|escape:'html':'UTF-8'}">
                            {$category.title|escape:'html':'UTF-8'}
                        </a>
                    </li>
                {/foreach}
            </ul>
        </aside>
        {/if}
        {if $categories|@count > 0}
            <div class="blog-content">
        {else}
            <div class="blog-content" style="width: 100%;">
        {/if}
            <h1>{$ourLatestPosts|escape:'html':'UTF-8'}</h1>
            <div class="blog-list">
            {foreach from=$posts item=post}
                <article class="blog-post" itemscope itemtype="https://schema.org/BlogPosting">
                    <a href="{$post->total_route|escape:'html':'UTF-8'}" class="blog-link">
                        <meta itemprop="url" content="{$post->total_route|escape:'html':'UTF-8'}">

                        {if $post->author}
                            <meta itemprop="author" content="{$post->author|escape:'html':'UTF-8'}">
                        {/if}

                        <meta itemprop="datePublished" content="{$post->date_published|date_format:'%Y-%m-%dT%H:%M:%SZ'|escape:'html':'UTF-8'}">

                        <div class="blog-img">
                            {if $post->cover_thumbnail_url}
                                <meta itemprop="image" content="{$post->cover_thumbnail_url|escape:'html':'UTF-8'}">
                                <img src="{$post->cover_thumbnail_url|escape:'html':'UTF-8'}" alt="{$post->title|escape:'html':'UTF-8'}" itemprop="image"/>
                            {/if}
                        </div>
                        <h2 itemprop="headline">{$post->title|escape:'html':'UTF-8'}</h2>
                        <p class="snippet" itemprop="description">{$post->snippet|escape:'html':'UTF-8'}</p>
                    </a>
                </article>
            {/foreach}
            </div>
        </div>
    </div>
    {if $total_pages > 1}
        <nav class="blog-pagination" aria-label="Pagination">
            <ul>
                {if $current_page > 1}
                    <li>
                        <a class="btn btn-secondary" href="{$module_link|escape:'html':'UTF-8'}?page={$current_page-1|escape:'html':'UTF-8'}">&laquo;</a>
                    </li>
                {/if}

                {section name=page loop=$total_pages}
                    {assign var=page_num value=$smarty.section.page.index+1}
                    {if $page_num == $current_page}
                        <li><span class="btn btn-primary">{$page_num|escape:'html':'UTF-8'}</span></li>
                    {else}
                        <li>
                            <a class="btn btn-secondary" href="{$module_link|escape:'html':'UTF-8'}?page={$page_num|escape:'html':'UTF-8'}">{$page_num|escape:'html':'UTF-8'}</a>
                        </li>
                    {/if}
                {/section}

                {if $current_page < $total_pages}
                    <li>
                        <a class="btn btn-secondary" href="{$module_link|escape:'html':'UTF-8'}?page={$current_page+1|escape:'html':'UTF-8'}">&raquo;</a>
                    </li>
                {/if}
            </ul>
        </nav>
    {/if}
{/block}
