{**
 * 2024 Sedestral
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@sedestral.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    Sedestral <contact@sedestral.com>
 * @copyright 2024 Sedestral
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 * International Registered Trademark & Property of Sedestral
*}
{extends file='page.tpl'}

{block name='page_content'}
    <article class="single-post" itemscope itemtype="https://schema.org/BlogPosting">
        <header>

            {if $post->author}
                <meta itemprop="author" content="{$post->author|escape:'html':'UTF-8'}"/>
            {/if}

            {if $post->cover_thumbnail_url}
                <meta itemprop="image" content="{$post->cover_thumbnail_url|escape:'html':'UTF-8'}"/>
                <meta property="og:image" content="{$post->cover_thumbnail_url|escape:'html':'UTF-8'}"/>
            {/if}

            <meta itemprop="datePublished" content="{$post->date_published|date_format:'%Y-%m-%dT%H:%M:%SZ'|escape:'html':'UTF-8'}"/>
            <meta itemprop="description" content="{$post->snippet|escape:'html':'UTF-8'}"/>
            <meta property="og:description" content="{$post->snippet|escape:'html':'UTF-8'}"/>

            <h1 itemprop="headline">{$post->title|escape:'html':'UTF-8'}</h1>
            {if $enable_post_header}
                <p class="author">
                    {if $post->author}
                        {$publishedBy|escape:'html':'UTF-8'} {$post->author|escape:'html':'UTF-8'}
                        {$on|escape:'html':'UTF-8'} {$post->date_published|date_format:"%d/%m/%Y %H:%M"|escape:'html':'UTF-8'}.
                    {else}
                        {$publishedOn|escape:'html':'UTF-8'} {$post->date_published|date_format:"%d/%m/%Y %H:%M"|escape:'html':'UTF-8'}.
                    {/if}
                </p>
            {/if}
        </header>
        <div class="content" itemprop="articleBody">
            {$post->content|cleanHtml nofilter}
        </div>
        {if $share_article}
        <div class="sedestral-social-share">
            <p>{$shareThisArticle|escape:'html':'UTF-8'}</p>
            <ul>
                <li>
                    <a href="https://www.facebook.com/sharer/sharer.php?u={$linkArticle|escape:'html':'UTF-8'}"
                       target="_blank"
                       rel="noopener noreferrer">
                        <img src="{$module_dir|escape:'html':'UTF-8'}views/img/facebook.png" alt="{$shareOnFacebook|escape:'html':'UTF-8'}">
                    </a>
                </li>
                <li>
                    <a href="https://x.com/share?url={$linkArticle|escape:'html':'UTF-8'}&text={$post->title|escape:'html':'UTF-8'}"
                       target="_blank"
                       rel="noopener noreferrer">
                        <img src="{$module_dir|escape:'html':'UTF-8'}views/img/x.png" alt="{$shareOnX|escape:'html':'UTF-8'}">
                    </a>
                </li>
                <li>
                    <a href="https://www.linkedin.com/sharing/share-offsite/?url={$linkArticle|escape:'html':'UTF-8'}"
                       target="_blank"
                       rel="noopener noreferrer">
                        <img src="{$module_dir|escape:'html':'UTF-8'}views/img/linkedin.png" alt="{$shareLikedIn|escape:'html':'UTF-8'}">
                    </a>
                </li>
                <li>
                    <a href="mailto:?subject={$post->title|escape:'html':'UTF-8'}&body={$linkArticle|escape:'html':'UTF-8'}"
                       target="_blank"
                       rel="noopener noreferrer">
                        <img src="{$module_dir|escape:'html':'UTF-8'}views/img/email.png" alt="{$shareEmail|escape:'html':'UTF-8'}">
                    </a>
                </li>
            </ul>
        </div>
        {/if}
    </article>
    {if $prev_post || $next_post}
        <div class="similar-articles">
            <h2>{$similarPosts|escape:'html':'UTF-8'}</h2>
            <div class="articles-list">
                {if $prev_post}
                    <article class="similar-article" itemscope itemtype="https://schema.org/BlogPosting">
                        <a href="{$prev_post->total_route|escape:'html':'UTF-8'}" class="blog-link">
                            <meta itemprop="url" content="{$prev_post->total_route|escape:'html':'UTF-8'}">

                            {if $prev_post->author}
                                <meta itemprop="author" content="{$prev_post->author|escape:'html':'UTF-8'}">
                            {/if}

                            <meta itemprop="datePublished" content="{$prev_post->date_published|date_format:'%Y-%m-%dT%H:%M:%SZ'|escape:'html':'UTF-8'}">

                            <div class="blog-img">
                                {if $prev_post->cover_thumbnail_url}
                                    <meta itemprop="image" content="{$prev_post->cover_thumbnail_url|escape:'html':'UTF-8'}">
                                    <img src="{$prev_post->cover_thumbnail_url|escape:'html':'UTF-8'}" alt="{$prev_post->title|escape:'html':'UTF-8'}" itemprop="image"/>
                                {/if}
                            </div>

                            <h2 itemprop="headline">{$prev_post->title|escape:'html':'UTF-8'}</h2>
                            <p class="snippet" itemprop="description">{$prev_post->snippet|escape:'html':'UTF-8'}</p>
                        </a>
                    </article>
                {/if}

                {if $next_post}
                    <article class="similar-article" itemscope itemtype="https://schema.org/BlogPosting">
                        <a href="{$next_post->total_route|escape:'html':'UTF-8'}" class="blog-link">
                            <meta itemprop="url" content="{$next_post->total_route|escape:'html':'UTF-8'}">

                            {if $next_post->author}
                                <meta itemprop="author" content="{$next_post->author|escape:'html':'UTF-8'}">
                            {/if}

                            <meta itemprop="datePublished" content="{$next_post->date_published|date_format:'%Y-%m-%dT%H:%M:%SZ'|escape:'html':'UTF-8'}">

                            <div class="blog-img">
                                {if $next_post->cover_thumbnail_url}
                                    <meta itemprop="image" content="{$next_post->cover_thumbnail_url|escape:'html':'UTF-8'}">
                                    <img src="{$next_post->cover_thumbnail_url|escape:'html':'UTF-8'}" alt="{$next_post->title|escape:'html':'UTF-8'}" itemprop="image"/>
                                {/if}
                            </div>
                            <h2 itemprop="headline">{$next_post->title|escape:'html':'UTF-8'}</h2>
                            <p class="snippet" itemprop="description">{$next_post->snippet|escape:'html':'UTF-8'}</p>
                        </a>
                    </article>
                {/if}
            </div>
        </div>
    {/if}
{/block}
